/**
 * Copyright (c) 2000-2009, Jasig, Inc.
 * See license distributed with this file and available online at
 * https://www.ja-sig.org/svn/jasig-parent/tags/rel-10/license-header.txt
 */
package org.jasig.portal.concurrency;

import org.jasig.portal.IBasicEntity;

/**
  * Defines the api for a cache that caches <code>IBasicEntities</code>
  * of a single type.
  *
  * @author Dan Ellentuck
  * @version $Revision: 17160 $
  */
public interface IEntityCache {
    
    /**
     * @param entity - the entity to be cached.
     */
    public void add(IBasicEntity entity) throws CachingException;
    
    /**
     * Purge stale entries from the cache.
     * @deprecated This is the responsibility of the cache or cache manager code
     */
    @Deprecated
    public void cleanupCache() throws CachingException;
    
    /**
     * Remove all entries from the cache.
     */
    public void clearCache() throws CachingException;
    
    /**
     * @param key the key of the entity.
     * @return org.jasig.portal.concurrency.IBasicEntity
     */
    public IBasicEntity get(String key);
    
    /**
     * @see org.jasig.portal.EntityTypes for known types.
     * @return java.lang.Class
     */
    public Class<? extends IBasicEntity> getEntityType();
    
    /**
     * @param entityKey - the key of the entity to be un-cached.
     */
    public void remove(String entityKey) throws CachingException;
    
    /**
     * Answers the number of entries in the cache. May return -1 if the cache does not make this
     * information avaialble
     */
    public int size();
    
    /**
     * @param entity - the entity to be updated in the cache.
     */
    public void update(IBasicEntity entity) throws CachingException;

}
